From: Suzuki K. Poulose <[email protected]>

If the primary kernel doesn't use an initrd,
we may not have linux,initrd-* entries in the
device-tree, and hence the initial flat tree
may not contain them.

Make sure we add the entries in the dtb if the
second kernel needs an initrd.

Signed-off-by: Suzuki K. Poulose <[email protected]>
Signed-off-by: Athira Rajeev<[email protected]>
---

 kexec/arch/ppc/fs2dt.c |   18 ++++++++++++++----
 1 files changed, 14 insertions(+), 4 deletions(-)

diff --git a/kexec/arch/ppc/fs2dt.c b/kexec/arch/ppc/fs2dt.c
index a49f85e..4121c7d 100644
--- a/kexec/arch/ppc/fs2dt.c
+++ b/kexec/arch/ppc/fs2dt.c
@@ -342,8 +342,17 @@ static void putnode(void)
 
        putprops(dn, namelist, numlist);
 
-       /* Add initrd entries to the second kernel */
-       if (initrd_base && !strcmp(basename, "chosen/")) {
+       /* 
+        * Add initrd entries to the second kernel
+        * if
+        *      a) a ramdisk is specified in cmdline
+        *       OR
+        *      b) reuseinitrd is specified and a initrd is
+        *         used by the kernel.
+        *
+        */
+       if ((ramdisk || (initrd_base && reuse_initrd))
+               && !strcmp(basename, "chosen/")) {
                int len = 8;
                unsigned long long initrd_end;
                *dt++ = 3;
@@ -362,8 +371,9 @@ static void putnode(void)
 
                memcpy(dt, &initrd_end, len);
                dt += (len + 3)/4;
-
-               reserve(initrd_base, initrd_size);
+               /* reserve the existing initrd image in case of reuse_initrd */
+               if (initrd_base && initrd_size && reuse_initrd)
+                       reserve(initrd_base, initrd_size);
        }
 
        for (i = 0; i < numlist; i++) {


_______________________________________________
kexec mailing list
[email protected]
http://lists.infradead.org/mailman/listinfo/kexec

Reply via email to